%global major   1
%define libname %mklibname fabric %major
%define devname %mklibname fabric -d

%global __remake_config 0

Name:           libfabric
Version:        1.22.0
Release:        %mkrel 3
Summary:        Open Fabric Interfaces
Group:          Emulators

License:        BSD or GPLv2
URL:            https://github.com/ofiwg/libfabric
Source0:        https://github.com/ofiwg/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.bz2
Patch1:		libfabric-gcc14.patch

%if %{__remake_config}
BuildRequires:  automake
BuildRequires:  autoconf
BuildRequires:  libtool
%endif
BuildRequires:  gcc
BuildRequires:  libnl3-devel
# RDMA not available on 32-bit ARM: #1484155
%ifnarch %{arm}
BuildRequires:  libibverbs-devel
BuildRequires:  librdmacm-devel
%endif
%ifarch x86_64
%if 0%{?fedora} || 0%{?rhel} == 7
BuildRequires:  infinipath-psm-devel
%endif
%if 0%{?fedora} || 0%{?rhel} >= 7
BuildRequires:  libpsm2-devel
%endif
BuildRequires:  numactl-devel
%endif

%description
OpenFabrics Interfaces (OFI) is a framework focused on exporting fabric
communication services to applications.  OFI is best described as a collection
of libraries and applications used to export fabric services.  The key
components of OFI are: application interfaces, provider libraries, kernel
services, daemons, and test applications.

Libfabric is a core component of OFI.  It is the library that defines and
exports the user-space API of OFI, and is typically the only software that
applications deal with directly.  It works in conjunction with provider
libraries, which are often integrated directly into libfabric.


%package        -n %libname
Summary:        Open Fabric Interfaces
Group:          System/Libraries

%description    -n %libname
OpenFabrics Interfaces (OFI) is a framework focused on exporting fabric
communication services to applications.  OFI is best described as a collection
of libraries and applications used to export fabric services.  The key
components of OFI are: application interfaces, provider libraries, kernel
services, daemons, and test applications.

Libfabric is a core component of OFI.  It is the library that defines and
exports the user-space API of OFI, and is typically the only software that
applications deal with directly.  It works in conjunction with provider
libraries, which are often integrated directly into libfabric.

%package        -n %devname
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Provides:       libfabric-devel = %{version}-%{release}

%description    -n %devname
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%autosetup -p1 %{name}-%{version}

%build
%if %{__remake_config}
./autogen.sh
%endif
%configure --disable-static --disable-silent-rules
%make_build


%install
%make_install


%files
%license COPYING
%{_bindir}/fi_info
%{_bindir}/fi_pingpong
%{_bindir}/fi_strerror
%{_mandir}/man1/*.1*

%files -n %libname
%{_libdir}/*.so.%{major}{,.*}

%files -n %devname
%license COPYING
%doc AUTHORS README
# We knowingly share this with kernel-headers and librdmacm-devel
# https://github.com/ofiwg/libfabric/issues/1277
%{_includedir}/rdma/
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/*.3*
%{_mandir}/man7/*.7*


%changelog
* Sun Dec 01 2024 wally <wally> 1.22.0-3.mga10
+ Revision: 2120509
- fix 32bit build with gcc14

* Sun Dec 01 2024 daviddavid <daviddavid> 1.22.0-2.mga10
+ Revision: 2120308
- new version: 1.22.0

* Sat Sep 16 2023 tv <tv> 1.19.0-1.mga10
+ Revision: 1987131
- Update to 1.16.1

* Sun Nov 06 2022 tv <tv> 1.16.1-1.mga9
+ Revision: 1904063
- Update to 1.16.1

* Sun Oct 09 2022 neoclust <neoclust> 1.15.2-1.mga9
+ Revision: 1896024
- New version 1.15.2

* Fri Jun 10 2022 tv <tv> 1.15.1-1.mga9
+ Revision: 1863886
- Update to 1.15.1

* Fri Mar 18 2022 umeabot <umeabot> 1.14.0-2.mga9
+ Revision: 1797959
- Mageia 9 Mass Rebuild

* Tue Nov 23 2021 tv <tv> 1.14.0-1.mga9
+ Revision: 1758736
- Update to upstream release v1.14.0
- Update to upstream release v1.14.0rc2

* Wed Nov 03 2021 tv <tv> 1.14.0-0.1.mga9
+ Revision: 1753818
- Update to upstream release v1.14.0rc1

* Thu Oct 28 2021 tv <tv> 1.13.2-0.1.mga9
+ Revision: 1753166
- Update to 1.13.2

* Thu Jun 24 2021 tv <tv> 1.13.0-0.1.mga9
+ Revision: 1732095
- Update to upstream release v1.13.0rc1

* Fri Apr 09 2021 tv <tv> 1.12.1-0.1.mga9
+ Revision: 1714260
- Update to upstream release v1.12.1
- Enable psm3 support

* Sun Feb 28 2021 tv <tv> 1.12.0-0.1.mga9
+ Revision: 1693307
- Update to upstream release v1.12.0rc1

* Wed Dec 16 2020 tv <tv> 1.11.2-2.mga8
+ Revision: 1658001
- Update to upstream release v1.11.2 (from rc1)

* Wed Dec 09 2020 tv <tv> 1.11.2-1.mga8
+ Revision: 1654889
- Update to upstream release v1.11.2rc1

* Mon Oct 12 2020 tv <tv> 1.11.1-1.mga8
+ Revision: 1633981
- 1.11.1

* Sun Sep 20 2020 tv <tv> 1.11.0-3.mga8
+ Revision: 1628906
- Update to 1.11. (#1869025)

* Wed Aug 05 2020 joequant <joequant> 1.6.2-3.mga8
+ Revision: 1611093
- fix deps

* Fri Feb 14 2020 umeabot <umeabot> 1.6.2-2.mga8
+ Revision: 1520250
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Nov 16 2018 tv <tv> 1.6.2-1.mga7
+ Revision: 1330167
- imported package libfabric


* Fri Nov 16 2018 Thierry Vignaud <tv@mageia.org> 1.6.2-1.mga7
- import from FC

* Mon Oct  8 2018 Honggang Li <honli@redhat.com> - 1.6.2-1
- Rebase libfabric to latest upstream release v1.6.2
- Resolves: bz1637334

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Jun 22 2018 Honggang Li <honli@redhat.com> - 1.6.1-1
- Rebase to latest upstream release 1.6.1
- Resolves: bz1550404

* Thu Mar 15 2018 Orion Poplawski <orion@nwra.com> - 1.6.0-1
- Update to 1.6.0

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 23 2017 Adam Williamson <awilliam@redhat.com> - 1.4.2-5
- Disable RDMA support on 32-bit ARM (#1484155)

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Sun Jul 30 2017 Florian Weimer <fweimer@redhat.com> - 1.4.2-3
- Rebuild with binutils fix for ppc64le (#1475636)

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Jul 11 2017 Orion Poplawski <orion@cora.nwra.com> - 1.4.2-1
- Update to 1.4.2

* Mon Apr 10 2017 Orion Poplawski <orion@cora.nwra.com> - 1.4.1-1
- Update to 1.4.1

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Nov 3 2016 Orion Poplawski <orion@cora.nwra.com> - 1.4.0-1
- Update to 1.4.0

* Thu Jul 21 2016 Orion Poplawski <orion@cora.nwra.com> - 1.3.0-3
- Rebuild for aarch64 glibc update

* Tue May 31 2016 Orion Poplawski <orion@cora.nwra.com> - 1.3.0-2
- Use psm/psm2 if possible on Fedora (bug #1340988)

* Tue Apr 12 2016 Orion Poplawski <orion@cora.nwra.com> - 1.3.0-1
- Update to 1.3.0

* Wed Mar 9 2016 Orion Poplawski <orion@cora.nwra.com> - 1.2.0-1
- Update to 1.2.0
- Use psm/psm2 if possible on EL
- Add upstream patch to fix non-x86 builds

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Aug 26 2015 Orion Poplawski <orion@cora.nwra.com> - 1.1.0-1
- Update to 1.1.0

* Mon Jul 20 2015 Orion Poplawski <orion@cora.nwra.com> - 1.0.0-1
- Initial package
